@@ -1,5 +1,5 @@
 #!/usr/local/bin/perl
-# $Header: parse.pl,v 1.8.1.1 95/05/11 03:56:02 stevens Exp $
+# $Id: parse.pl,v 2.3 1995/07/08 11:02:14 children Beta $
 #                      Perl Empire Interface Parser
 #
 #                Written by Drake Diedrich and Sam Tetherow
@@ -22,8 +22,7 @@
 #
 # BUG REPORTS:
 # mail your bug-reports and comments to:
-# children@empire.net (Ken Stevens)
-# tetherow@cse.unl.edu (Sam Tetherow)
+# tetherow@nol.org (Sam Tetherow)
  
 #       --- Global variables ---
 #
@@ -499,6 +498,9 @@ sub parse_nation {
     $maxciv=$1;
     $maxuw=$2;
   }
+  elsif (/^Nation status is (\S+)\s/) {
+    $nstatus = $1;
+  }
 }
 
 sub parse_radar {
@@ -533,8 +535,15 @@ sub parse_relations {
 }
  
 sub parse_report {
-# Not sure if we want to try and do some estimating here or not
-  if (/^\s*(\d+)\s+(.+)\s+(backward|similar|primitive|advanced|superior)\s+(primitive|backward|similar|advanced|superior)\s+(primitive|backward|similar|advanced|superior)\s+(.+)\s*$/) {
+  if (/^\s*(\d+)\s+(.+)\s+(> \d+|\d+ - \d+)\s+\s+(> \d+|\d+ - \d+)\s+(> \d+|\d+ - \d+)\s+(> \d+|\d+ - \d+)\s+(.+)\s*$/) {
+    $country{$1}=$2;
+    $number{$2}=$1;
+    $tech{$1}=$3;
+    $res{$1}=$4;
+    $edu{$1}=$5;
+    $hap{$1}=$6;
+    $status{$1}=$7;
+  } elsif (/^\s*(\d+)\s+(.+)\s+(backward|similar|primitive|advanced|superior)\s+(primitive|backward|similar|advanced|superior)\s+(primitive|backward|similar|advanced|superior)\s+(.+)\s*$/) {
     $country{$1}=$2;
     $number{$2}=$1;
     $tech{$1}=$3;
@@ -821,6 +830,7 @@ sub parse_ship_build {
   if (/^(\S+\D*\d*) +(\d+) +(\d+) +(\d+) +(\d+) \$(\d+)$/) {
     local($lcm, $hcm, $avail, $tech, $cost)=($2, $3, $4, $5, $6);
     local($type)=$1; $type=~s/\s*$//;
+    $type = substr($type,0,16) if length $type > 16;
     $shipname{$type}=$type;
     $buildlcm{$type}=$lcm;
     $buildhcm{$type}=$hcm;
@@ -847,6 +857,7 @@ sub parse_ship_stats {
   if (/^(\S+\D*\d*) +(\d+) +(\d+) +(\d+) +(\d+) +(\d+) +(\d+) +(\d+) +(\d+) +(\d+) +(\d+) +(\d+)\/(\d+)/) {
     local($def, $spd, $vis, $spy, $frg, $fir, $lnd, $pln, $hel, $xpl, $car, $use)=($2, $3, $4, $5, $6, $7, $8, $9, $10, $11, $12, $13);
     local($type)=$1; $type=~s/\s*$//;
+    $type = substr($type,0,16) if length $type > 16;
     $shipdef{$type} = $def;
     $shipspd{$type} = $spd;
     $visibility{$type} = $vis;
@@ -1015,8 +1026,11 @@ sub parse_cargo {
  
  
 sub parse_plane {
-  if (/^\s*(\d+)\s+(\S+\D*\d*)\s+(\S+,\S+)\s+(\S?)\s+(\d+)\%\s+(\S+)\s+(\S+)\s+([\d-]+)\s+(\d+)\s+(\d+)\s+(\d+)\s*(.*)/) {
-    local($unit, $sect, $wing, $eff, $mob, $att, $def, $tech, $ran, $hard, $sln)=($1, $3, $4, $5, $6, $7, $8, $9, $10, $11, $12);
+				# Empire2
+  if (/^\s*(\d+)\s+(\S+\D*\d*)\s+(\S+,\S+)\s+(\S?)\s+(\d+)\%\s+(\S+)\s+([\d-]+)\s+(\d+)\s+(\d+)\s+(\d+)\s*(.*)/ ||
+				# Chainsaw
+      /^\s*(\d+)\s+(\S+\D*\d*)\s+(\S+,\S+)\s+(\S?)\s+(\d+)\%\s+(\S+)\s+(\S+)\s+[\d-]+\s+(\d+)\s+(\d+)\s+(\d+)\s*(.*)/) {
+    local($unit, $sect, $wing, $eff, $mob, $att, $tech, $ran, $hard, $sln)=($1, $3, $4, $5, $6, $7, $8, $9, $10, $11);
     local($type)=substr($2,0,19); $type=~s/\s*$//;
     $planename{$unit}=$planename{$type};
     $planesect{$unit}=$sect;
@@ -1024,7 +1038,6 @@ sub parse_plane {
     $planeeff{$unit}=$eff;
     $planemob{$unit}=$mob;
     $planeatt{$unit}=$att;
-    $planedef{$unit}=$def;
     $planetech{$unit}=$tech;
     $planeran{$unit}=$ran;
     $planehard{$unit}=$hard;
